OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "לא ניתן לכתוב לתיקיית \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "בדרך כלל ניתן לפתור את הבעיה על ידי כך שנותנים ל- webserver הרשאות כניסה לתיקיית config",
    "See %s" : "ניתן לראות %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "בדרך כלל ניתן לפתור את הבעיה על ידי כך ש- %s נותן ל- webserver הרשאות כניסה לתיקיית config %s.",
    "Sample configuration detected" : "התגלתה דוגמת תצורה",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "התגלה שדוגמת התצורה הועתקה. דבר זה עלול לשבור את ההתקנה ולא נתמך. יש לקרוא את מסמכי התיעוד לפני שמבצעים שינויים ב- config.php",
    "PHP %s or higher is required." : "נדרש PHP בגרסת %s ומעלה.",
    "PHP with a version lower than %s is required." : "נדרש PHP בגרסה נמוכה מ- %s.",
    "%sbit or higher PHP required." : "נדרש PHP בגרסת %s ומעלה.",
    "Following databases are supported: %s" : "מסדי הנתונים הבאים נתמכים: %s",
    "The command line tool %s could not be found" : "כלי שורת הפקודה %s לא אותר",
    "The library %s is not available." : "הספריה %s אינה זמינה.",
    "Library %s with a version higher than %s is required - available version %s." : "ספריה %s בגרסה גבוהה מ- %s נדרשת - גרסה זמינה %s.",
    "Library %s with a version lower than %s is required - available version %s." : "ספריה %s בגרסה נמוכה מ- %s נדרשת - גרסה זמינה %s.",
    "Following platforms are supported: %s" : "הפלטפורמות הבאות נתמכות: %s",
    "ownCloud %s or higher is required." : "נדרש ownCloud %s ומעלה.",
    "ownCloud %s or lower is required." : "נדרש ownCloud %s ומטה.",
    "Unknown filetype" : "סוג קובץ לא מוכר",
    "Invalid image" : "תמונה לא חוקית",
    "Avatar image is not square" : "תמונת דמות מייצגת, אווטאר, אינה ריבועית",
    "today" : "היום",
    "yesterday" : "אתמול",
    "_%n day ago_::_%n days ago_" : ["לפני %n יום","לפני %n ימים"],
    "last month" : "חודש שעבר",
    "last year" : "שנה שעברה",
    "_%n year ago_::_%n years ago_" : ["לפני %n שנה","לפני %n שנים"],
    "seconds ago" : "שניות",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "מודול עם זהות: %s אינו קיים. יש לאפשר את זה בהגדרות היישומים או ליצור קשר עם המנהל.",
    "Builtin" : "מובנה",
    "None" : "כלום",
    "Username and password" : "שם משתמש וסיסמא",
    "Username" : "שם משתמש",
    "Password" : "סיסמא",
    "Log-in credentials, save in session" : "אישורי התחברות, נשמרים במידע שיחה - סשן",
    "Empty filename is not allowed" : "שם קובץ ריק אינו מאושר",
    "Dot files are not allowed" : "קבצי Dot אינם מותרים",
    "4-byte characters are not supported in file names" : "תווי 4-byte אינם נתמכים בשמות קבצים",
    "File name is a reserved word" : "שם קובץ הנו מילה שמורה",
    "File name contains at least one invalid character" : "שם קובץ כולל לפחות תו אחד לא חוקי",
    "File name is too long" : "שם קובץ ארוך מדי",
    "App directory already exists" : "תיקיית יישום כבר קיימת",
    "Can't create app folder. Please fix permissions. %s" : "לא ניתן ליצור תיקיית יישום. יש לתקן הרשאות. %s",
    "Archive does not contain a directory named %s" : "הארכיב לא כולל שם תיקייה %s",
    "No source specified when installing app" : "לא נקבע מקור בתהליך התקנת היישום",
    "No href specified when installing app from http" : "לא נקבע href בתהליך התקנת היישום מהאינטרנט",
    "No path specified when installing app from local file" : "לא נקבע נתיב בתהליך התקנת היישום מקובץ מקומי",
    "Archives of type %s are not supported" : "ארכיבים מסוג %s אינם נתמכים",
    "Failed to open archive when installing app" : "פתיחת ארכיב נכשלה בתהליך התקנת היישום",
    "App does not provide an info.xml file" : "היישום לא סיפק קובץ info.xml",
    "App cannot be installed because appinfo file cannot be read." : "היישום לא ניתן להתקנה כיוון שקובץ appinfo לא ניתן לקריאה.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "חתימה לא ניתנת לבדיקה. יש ליצור קשר עם מפתח היישום ולבדוק את מסך הניהול.",
    "App can't be installed because of not allowed code in the App" : "היישום לא ניתן להתקנה בשל קוד אסור ביישום",
    "App can't be installed because it is not compatible with this version of ownCloud" : "היישום לא ניתן להתקנה כיוון שהוא אינו תואם את גרסת ה- ownCloud הזו",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "יישום לא ניתן להתקנה כייון שכולל תווית <shipped>אמת</shipped> tag שאינו מאושר ליישומים שאינם נשלחים",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "לא ניתן להתקין את היישום כיוון שהגרסה בקובץ info.xml אינה תואמת לגרסה שמתקבלת מחנות היישומים",
    "Apps" : "יישומים",
    "General" : "כללי",
    "Storage" : "אחסון",
    "Security" : "אבטחה",
    "User Authentication" : "אימות משתמש",
    "Encryption" : "הצפנה",
    "Workflows & Tags" : "זרימת עבודה ותוויות",
    "Sharing" : "שיתוף",
    "Search" : "חיפוש",
    "Updates" : "עדכונים",
    "Help & Tips" : "עזרה וטיפים",
    "Additional" : "נוספים",
    "%s enter the database username and name." : "%s יש להכניס את שם המשתמש ושם מסד הנתונים.",
    "%s enter the database username." : "%s נכנס למסד נתוני שמות המשתמשים.",
    "%s enter the database name." : "%s נכנס למסד נתוני השמות.",
    "%s you may not use dots in the database name" : "%s לא ניתן להשתמש בנקודות בשם מסד הנתונים",
    "Oracle connection could not be established" : "לא ניתן היה ליצור חיבור Oracle",
    "Oracle username and/or password not valid" : "שם משתמש ו/או סיסמת Oracle אינם תקפים",
    "DB Error: \"%s\"" : "שגיאת מסד נתונים: \"%s\"",
    "Offending command was: \"%s\"" : "הפקודה המזיקה הייתה: \"%s\"",
    "You need to enter either an existing account or the administrator." : "יש להכניס חשבון קיים או מנהל.",
    "Offending command was: \"%s\", name: %s, password: %s" : "הפקודה המזיקה הייתה: \"%s\", שם: %s, סיסמא: %s",
    "PostgreSQL username and/or password not valid" : "שם משתמש ו/או סיסמת PostgreSQL אינם תקפים",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X אינו נתמך ו- %s לא יעבוד כשורה בפלטפורמה זו. ניתן לקחת סיכון ולהשתמש באחריותך! ",
    "For the best results, please consider using a GNU/Linux server instead." : "לתוצאות הכי טובות, יש לשקול שימוש בשרת GNU/Linux במקום.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "נראה ש- %s עובד על בסיס סביבת 32-bit PHP ושה- open_basedir הוגדר בקובץ php.ini. מצב זה יוביל לבעיות עם קבצים הגדולים מ- 4 GB ואינו מומלץ לחלוטין.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "יש להסיר את הגדרת open_basedir מתוך קובץ php.ini או להחליף לסביבת 64-bit PHP.",
    "Set an admin username." : "קביעת שם משתמש מנהל",
    "Set an admin password." : "קביעת סיסמת מנהל",
    "Can't create or write into the data directory %s" : "לא ניתן ליצור או לכתוב לתוך תיקיית הנתונים %s",
    "Invalid Federated Cloud ID" : "זיהוי ענן מאוגד לא חוקי",
    "%s shared »%s« with you" : "%s שיתף/שיתפה איתך את »%s«",
    "%s via %s" : "%s על בסיס %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "השיתוף %s נכשל, כיוון שהצד האחורי אינו מאפשר שיתופים מסוג %i",
    "Sharing %s failed, because the file does not exist" : "השיתוף %s נכשל, כיוון שהקובץ אינו קיים",
    "You are not allowed to share %s" : "אינך רשאי/ת לשתף %s",
    "Sharing %s failed, because you can not share with yourself" : "השיתוף %s נכשל, כיוון שלא ניתן לשתף עם עצמך",
    "Sharing %s failed, because the user %s does not exist" : "השיתוף %s נכשל, כיוון שהמשתמש %s אינו קיים",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "השיתוף %s נכשל, כיוון שהמשתמש %s אינו חבר בקבוצות ש- %s חבר ב-",
    "Sharing %s failed, because this item is already shared with %s" : "שיתוף %s נכשל, כיוון שפריט זה כבר משותף עם %s",
    "Sharing %s failed, because this item is already shared with user %s" : "השיתוף %s נכשל, כיוון שהפריט כבר משותף עם משתמש %s",
    "Sharing %s failed, because the group %s does not exist" : "השיתוף %s נכשל, כיוון שהקבוצה %s אינה קיימת",
    "Sharing %s failed, because %s is not a member of the group %s" : "השיתוף %s נכשל, כיוון ש- %s אינו חבר בקבוצה %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "יש לספק סיסמא ליצירת קישור ציבורי, רק קישורים מוגנים מותרים",
    "Sharing %s failed, because sharing with links is not allowed" : "השיתוף %s נכשל, כיוון ששיתוף עם קישור אינו מותר",
    "Not allowed to create a federated share with the same user" : "אסור ליצור שיתוף מאוגד עם אותו משתמש",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "שיתוף %s נכשל, לא ניתן לאתר %s, ייתכן שהשרת לא ניתן להשגה כרגע.",
    "Share type %s is not valid for %s" : "שיתוף מסוג %s אינו תקף ל- %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "הגדרת הרשאות ל- %s נכשלה, כיוון שההרשאות עולים על האישורים שניתנו ל- %s",
    "Setting permissions for %s failed, because the item was not found" : "הגדרת הרשאות ל- %s נכשלה, כיוון שהפריט לא נמצא",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "לא ניתן לקבוע תאריך תפוגה. שיתופים אינם יכולים לפוג תוקף מאוחר יותר מ- %s לאחר ששותפו",
    "Cannot set expiration date. Expiration date is in the past" : "לא ניתן לקבוע תאריך תפוגה. תאריך התפוגה הנו בעבר",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "לא ניתן לבטל תאריך תפוגה. שיתופים חייבים להכיל תאריך תפוגה.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "צד אחורי לשיתוף %s חייב ליישם את ממשק OCP\\Share_Backend",
    "Sharing backend %s not found" : "צד אחורי לשיתוף %s לא נמצא",
    "Sharing backend for %s not found" : "צד אחורי לשיתוף של %s לא נמצא",
    "Sharing failed, because the user %s is the original sharer" : "שיתוף נכשל, כיוון שמשתמש %s הנו המשתף המקורי",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "השיתוף %s נכשל, כיוון שההרשאות עלו על ההרשאות שניתנו ל- %s",
    "Sharing %s failed, because resharing is not allowed" : "השיתוף %s נכשל, כיוון ששיתוף מחודש אסור",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "השיתוף %s נכשל, כיוון שבצד אחורי לשיתוף עבור %s לא ניתן היה לאתר את מקורו",
    "Sharing %s failed, because the file could not be found in the file cache" : "השיתוף %s נכשל, כייון שלא ניתן היה למצוא את הקובץ בזכרון המטמון",
    "Cannot increase permissions of %s" : "לא ניתן להגדיל את ההיתרים של %s",
    "Files can't be shared with delete permissions" : "קובץ לא ניתן לשיתוף בפעולת מחיקת הרשאות",
    "Files can't be shared with create permissions" : "קובץ לא ניתן לשיתוף בפעולת יצירת הרשאות",
    "Expiration date is in the past" : "תאריך תפוגה הנו בעבר",
    "Cannot set expiration date more than %s days in the future" : "לא ניתן להגדיר את תאריך התפוגה מעל %s ימים בעתיד",
    "Could not find category \"%s\"" : "לא ניתן למצוא את הקטגוריה „%s“",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "רק התווים הבאים מאושרים לשם משתמש: \"a-z\", \"A-Z\", \"0-9\", וגם \"_.@-'\"",
    "A valid username must be provided" : "יש לספק שם משתמש תקני",
    "Username contains whitespace at the beginning or at the end" : "שם המשתמש מכיל רווח בתחילתו או בסופו",
    "A valid password must be provided" : "יש לספק ססמה תקנית",
    "The username is already being used" : "השם משתמש כבר בשימוש",
    "Login canceled by app" : "התחברות בוטלה על ידי יישום",
    "User disabled" : "משתמש מנוטרל",
    "Help" : "עזרה",
    "Settings" : "הגדרות",
    "Users" : "משתמשים",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "היישום \"%s\" לא ניתן להתקנה כיוון שיחסי התלות הבאים אינם מתקיימים: %s",
    "web services under your control" : "שירותי רשת תחת השליטה שלך",
    "File is currently busy, please try again later" : "הקובץ בשימוש כרגע, יש לנסות שוב מאוחר יותר",
    "Can't read file" : "לא ניתן לקרוא קובץ",
    "Application is not enabled" : "יישומים אינם מופעלים",
    "Authentication error" : "שגיאת הזדהות",
    "Token expired. Please reload page." : "פג תוקף. נא לטעון שוב את הדף.",
    "Unknown user" : "משתמש לא ידוע",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "לא מותקנים דרייברים למסד הנתונים (sqlite, mysql, או postgresql).",
    "Cannot write into \"config\" directory" : "לא ניתן לכתוב לתיקיית \"config\"!",
    "Cannot write into \"apps\" directory" : "לא ניתן לכתוב לתיקיית \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "בדרך כלל ניתן להסתדר על ידי %s מתן הרשאות כתיבה בשרת האינטרנט לתיקיית היישומים %s או נטרול חנות היישומים בקובץ ה- config.",
    "Cannot create \"data\" directory" : "לא ניתן ליצור תיקיית \"data\"",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "זה בדרך כלל ניתן לתיקון על ידי <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">מתן הרשאות כתיבה בשרת לתיקיית הבסיס directory</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "הרשאות ניתנות בדרך כלל לתיקון על ידי %s מתן לשרת האינטרנט גישת כתיבה לתיקיית הבסיס %s.",
    "Setting locale to %s failed" : "הגדרת שפה ל- %s נכשלה",
    "Please install one of these locales on your system and restart your webserver." : "יש להתקין אחת מהשפות על המערכת שלך ולהפעיל מחדש את שרת האינטרנט.",
    "Please ask your server administrator to install the module." : "יש לבקש ממנהל השרת שלך להתקין את המודול.",
    "PHP module %s not installed." : "מודול PHP %s אינו מותקן.",
    "PHP setting \"%s\" is not set to \"%s\"." : "הגדרות PHP \"%s\" אינם מוגדרות ל- \"%s\"",
    "Adjusting this setting in php.ini will make ownCloud run again" : "שינוי הגדרה זו בקובץ php.ini יאפשר ל- ownCloud לרוץ שוב",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload מוגדר ל- \"%s\" במקום הערך המצופה \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "לתיקון בעיה זו יש להגדיר <code>mbstring.func_overload</code> כ- <code>0</code> iבקובץ ה- php.ini שלך",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 נדרש לכל הפחות. כרגע %s מותקן.",
    "To fix this issue update your libxml2 version and restart your web server." : "לתיקון הבעיה יש לעדכן את גרסת ה- libxml2 שלך ולהפעיל מחדש את שרת האינטרנט שלך.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ככל הנראה מוגדר ל- strip inline doc blocks. זה יגרום למספר יישומי ליבה לא להיות נגישים.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "זה ככל הנראה נגרם על ידי מאיץ/מטמון כמו Zend OPcache או eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "מודולי PHP הותקנו, אך עדיין רשומים כחסרים?",
    "Please ask your server administrator to restart the web server." : "יש לבקש ממנהל השרת שלך להפעיל מחדש את שרת האינטרנט.",
    "PostgreSQL >= 9 required" : "נדרש PostgreSQL >= 9",
    "Please upgrade your database version" : "יש לשדרג את גרסת מסד הנתונים שלך",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "יש לשנות את ההרשאות ל- 0770 כך שהתיקייה לא תרשם על ידי משתמשים אחרים.",
    "Your Data directory is readable by other users" : "תיקיית Data שלך ניתנת לקריאה על ידי משתמשים אחרים",
    "Your Data directory must be an absolute path" : "תיקיית Data שלך חייבת להיות כנתיב אבסולוטי",
    "Check the value of \"datadirectory\" in your configuration" : "יש לבדוק את הערך \"datadirectory\" בהגדרות התצורה שלך",
    "Your Data directory  is invalid" : "תיקיית Data שלך אינה חוקית",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "יש לוודא שתיקיית המידע כוללת קובץ \".ocdata\" בנתיב הבסיס שלה",
    "Could not obtain lock type %d on \"%s\"." : "לא ניתן היה להשיג סוג נעילה %d ב- \"%s\".",
    "Storage unauthorized. %s" : "אחסון לא מורשה. %s",
    "Storage incomplete configuration. %s" : "תצורה לא מושלמת של האחסון. %s",
    "Storage connection error. %s" : "שגיאת חיבור אחסון. %s",
    "Storage is temporarily not available" : "אחסון באופן זמני אינו זמין",
    "Storage connection timeout. %s" : "פסק זמן חיבור אחסון. %s",
    "A safe home for all your data" : "בית בטוח לכל המידע שלך",
    "The username must be at least 3 characters long" : "שם המשתמש חייב להיות באורך של 3 תווים לכל היותר",
    "File cannot be read" : "קובץ לא ניתן לקריאה",
    "%s is not supported and %s will not work properly on this platform. Use it at your own risk! " : "%s אינו נתמך וכן %s לא יעבוד באופן תקין בפלטפורמה זו. שימוש באחריותך בלבד! ",
    "Sharing %s failed, could not find %s, check spelling and server availability." : "השיתוף של %s נכשל, לא ניתן למצוא %s, יש לבדוק את האיות ואת זמינות השרת.",
    "Imprint" : "חותמת",
    "__language_name__" : "עברית"
},
"nplurals=2; plural=(n != 1);");
